@@ -591,7 +591,7 @@ setMethod(f = "sosGetCRS",
 
 
 ################################################################################
-# Access to changes and other documents shipping with the package
+# Access to CHANGES and NEWS shipping with the package
 #
 #
 sosChanges <- function() {
@@ -604,6 +604,16 @@ sosChanges <- function() {
 	cat(.lines, sep = "\n")
 }
 
+sosNews <- function() {
+	.path <- paste(.find.package("sos4R", lib.loc = NULL), "NEWS",
+			sep = "\\")
+	.con <- file(.path)
+	.lines <- readLines(.con)
+	close(.con)	
+	
+	cat(.lines, sep = "\n")
+}
+
 # based on vignette-function
 sosCheatSheet <- function() {
 	.path <- paste(.find.package("sos4R", lib.loc = NULL), "doc",
