@@ -283,7 +283,7 @@ SosGetObservationById <- function(
 			print(.encodedRequest)
 		}
 		
-		# TODO SOAP request method
+		# TODO add SOAP request method
 	}
 	else {
 		stop(paste("Unsupported method, has to be one of",
@@ -1328,6 +1328,23 @@ setMethod(f = "encodeXML",
 		}
 )
 
+#
+# to make just the time encoding interchangeable by users
+#
+setMethod(f = "encodeXML",
+		signature = signature(obj = "POSIXt", sos = "SOS"),
+		def = function(obj, sos, verbose = FALSE) {
+			if(verbose) cat("[encodeXML] POSIXt with value", toString(obj),
+						"\n")
+			
+			.formatted <- strftime(x = obj, format = sosTimeFormat(sos))
+			
+			if(verbose)
+				cat("Formatted ", obj, " to ", .formatted)
+			
+			return(.formatted)
+		}
+)
 
 #
 # 
@@ -1359,6 +1376,24 @@ setMethod(f = "encodeKVP",
 		}
 )
 
+#
+# to make just the time encoding interchangeable by users
+#
+setMethod(f = "encodeKVP",
+		signature = signature(obj = "POSIXt", sos = "SOS"),
+		def = function(obj, sos, verbose) {
+			if(verbose) cat("[encodeKVP] POSIXt with value", toString(obj),
+						"\n")
+			
+			.formatted <- strftime(obj = obj, format = sosTimeFormat(sos))
+			
+			if(verbose)
+				cat("Formatted ", obj, " to ", .formatted)
+			
+			return(.formatted)
+		}
+)
+
 
 ################################################################################
 #
